/**************************************************************************
CmdModeHard.c
A7 Engineering, 2004

This program is used with RCM3000, RCM3100, RCM3200, RCM3300, and
RCM3400 series controllers with an EmbeddedBlue eb506 radio module.

Description
===========
This program demonstrates switching between command and data mode
using the mode control I/O line.

Instructions
============
1. Verify that the eb506 is configured to use serial port F through
    jumpers J1 and J2.
2. Modify the connection logic to use the correct Bluetooth Address.
3. Compile and run this program.

**************************************************************************/
#use a7eng_eb506.lib
#class auto

#define BAUD_RATE 9600L
#define BUFFER_SIZE 32

void main()
{
  auto char szPortFData[BUFFER_SIZE];
  memset(szPortFData, 0, sizeof(szPortFData));

  // Open the serial port for communications and initialize the eb506
  serFopen(BAUD_RATE);
  a7_serFeb506Init();

  // Connect to the remote device
  serFputs("con 00:11:22:33:44:55\r");
  a7_serFwaitForString("ACK\r", 0);

  // Wait for the connection to be established and switch into data mode.
  // When switching into data mode, a 300ms timeout is required to give the
  // module enough time to make the change.
  while(!BitRdPortI(PDDR, 4));
  BitWrPortI(PDDR, &PDDRShadow, 1, 5);
  a7_pauseMs(300);

  printf("Connection established\n");

  serFputs("This string is sent in data mode\r");

  // Verify all data has been transmitted and switch to Command Mode
  while(serFwrFree() != FOUTBUFSIZE);
  BitWrPortI(PDDR, &PDDRShadow, 0, 5);
  a7_serFwaitForString("\r>", 0);

  printf("In Command Mode\n");

  // Get local eb506 Bluetooth Address
  serFputs("get address\r");
  a7_serFwaitForString("ACK\r", 0);

  // Read local address from get command
  while(serFpeek() == -1) {}
  serFread(szPortFData, 17, 100);
  szPortFData[17] = '\r';
  printf("Local eb506 address: %s\n", szPortFData);
  a7_serFwaitForString("\r>", 0);

  // Return to data mode
  BitWrPortI(PDDR, &PDDRShadow, 1, 5);
  a7_pauseMs(300);

  // Send data through eb506
  serFputs("My eb506 address is ");
  serFputs(szPortFData);

  // Verify all data has been transmitted and switch to Command Mode
  while(serFwrFree() != FOUTBUFSIZE);
  BitWrPortI(PDDR, &PDDRShadow, 0, 5);
  a7_serFwaitForString("\r>", 0);

  printf("In Command Mode\n");

  // Disconnect from the remote device
  serFputs("dis\r");
  a7_serFwaitForString("\r>", 0);

  printf("Disconnected\n");

  serFclose();
}