/**************************************************************************
FlowControl.c
A7 Engineering, 2004

This program is used with RCM3000, RCM3100, RCM3200, RCM3300, and
RCM3400 series controllers with an EmbeddedBlue eb506 radio module.

Description
===========
This sample demonstrates a simple pass through application that uses flow
control both for eb506 and PC communications. This sample uses the RS232
level translation chip built into the RCM30/31/32XX serial prototyping
board to communicate with a standard PC serial port.

Instructions
============
1. Verify that the eb506 is configured to use serial port F through
    jumpers J1 and J2.
2. Connect header J5 on the prototyping board to the PC using pins 3 and
    5 for Tx and Rx and pins 4 and 6 for RTS and CTS.
3. Compile and run this program on the RabbitCore module using the
    "PROG" cable.

**************************************************************************/

#define SERB_CTS_PORT PCDR
#define SERB_CTS_BIT 3
#define SERB_RTS_PORT PCDR
#define SERB_RTS_SHADOW PCDRShadow
#define SERB_RTS_BIT 2

#define SERF_CTS_PORT PDDR
#define SERF_CTS_BIT 3
#define SERF_RTS_PORT PDDR
#define SERF_RTS_SHADOW PDDRShadow
#define SERF_RTS_BIT 2

#use a7eng_eb506.lib
#class auto

#define BAUD_RATE 9600L
#define BUFFER_SIZE 32

void main()
{
  auto char szPortBData[BUFFER_SIZE];
  auto char szPortFData[BUFFER_SIZE];
  auto int nDataAvailableOnB, nDataAvailableOnF;
  auto int nDataReadFromB, nDataReadFromF;

  // Configure the data direction registers for the RTS and CTS bits.
  // This register defaults to all inputs. We need to set the RTS line
  // to an output and the CTS as an input since the eb506 is a DCE.
  WrPortI(PDDDR, &PDDDRShadow, 0x04 | PDDDRShadow);
  WrPortI(PDDR, &PDDRShadow, 0x04 | PDDRShadow);

  WrPortI(PCDR, &PCDRShadow, 0x04 | PCDRShadow);

  // Open the serial port for communications and initialize the eb506
  serBopen(BAUD_RATE);
  serFopen(BAUD_RATE);
  serBflowcontrolOn();
  serFflowcontrolOn();

  a7_serFeb506Init();

  while(1)
  {
    BigLoopTop();

    // Read data from the diagnostics port and send it to the eb506
    costate
    {
      nDataAvailableOnB = serBrdUsed();

      // Ensure we don't overflow our buffer
      if(nDataAvailableOnB > BUFFER_SIZE)
        nDataAvailableOnB = BUFFER_SIZE;

      if(nDataAvailableOnB > 0)
      {
        wfd nDataReadFromB = cof_serBread(szPortBData, nDataAvailableOnB, 50);
        wfd cof_serFwrite(szPortBData, nDataReadFromB);
      }
    }

    // Read data from the eb506 and send it to the diagnostics port
    costate
    {
      nDataAvailableOnF = serFrdUsed();

      // Ensure we don't overflow our buffer
      if(nDataAvailableOnF > BUFFER_SIZE)
        nDataAvailableOnF = BUFFER_SIZE;

      if(nDataAvailableOnF > 0)
      {
        wfd nDataReadFromF = cof_serFread(szPortFData, nDataAvailableOnF, 50);
        wfd cof_serBwrite(szPortFData, nDataReadFromF);
      }
    }
  }
}