/**************************************************************************
GetAddress.c
A7 Engineering, 2004

This program is used with RCM3000, RCM3100, RCM3200, RCM3300, and
RCM3400 series controllers with an EmbeddedBlue eb506 radio module.

Description
===========
This sample demonstrates how to get the bluetooth address of the eb506.

Instructions
============
1. Verify that the eb506 is configured to use serial port F through
    jumpers J1 and J2.
2. Compile and run this program on the RabbitCore module using the
    "PROG" cable.
3. The bluetooth address of the eb506 module will be displayed in
    the debug output window in the Dynamic C Development environemnt.

**************************************************************************/
#use a7eng_eb506.lib
#class auto

#define BAUD_RATE 9600L
#define BUFFER_SIZE 32

void main()
{
  auto char szPortFData[BUFFER_SIZE];
  auto int nBytesRead;

  // Open the serial port for communications and initialize the eb506
  serFopen(BAUD_RATE);
  a7_serFeb506Init();

  // Request eb506 address
  serFputs("get address\r");
  a7_serFwaitForString("ACK\r", 0);

  // Read local address from get command
  while(serFpeek() == -1) {}
  nBytesRead = serFread(szPortFData, 17, 50);
  if(nBytesRead > 0)
  {
    szPortFData[17] = 0;
    printf("eb506 address: %s\n", szPortFData);
  }
}