/**************************************************************************
HelloWorld.c
A7 Engineering, 2004

This program is used with RCM3000, RCM3100, RCM3200, RCM3300, and
RCM3400 series controllers with an EmbeddedBlue eb506 radio module.

Description
===========
This sample demonstrates communications from an eb506 module to
another bluetooth device.

Instructions
============
1. Verify that the eb506 is configured to use serial port F through
    jumpers J1 and J2.
2. Modify the connection logic to use the correct Bluetooth Address.
3. Compile and run this program on the RabbitCore module using the
    "PROG" cable.

**************************************************************************/
#use a7eng_eb506.lib
#class auto

#define BAUD_RATE 9600L

void main()
{
  auto int nCounter;

  serFopen(BAUD_RATE);
  a7_serFeb506Init();

  // Connect to the remote device
  serFputs("con 00:11:22:33:44:55\r");
  a7_serFwaitForString("ACK\r", 0);

  // Wait for the connection to be established and switch into data mode.
  // When switching into data mode, a 300ms timeout is required to give the
  // module enough time to make the change.
  while(!BitRdPortI(PDDR, 4));
  BitWrPortI(PDDR, &PDDRShadow, 1, 5);
  a7_pauseMs(300);

  printf("Connection established\n");

  // Send "Hello World" ten times
  for(nCounter = 0; nCounter < 10; nCounter++)
  {
    serFputs("Hello World\r");
    a7_pauseMs(1000);
  }

  // Verify all data has been transmitted and switch to Command Mode
  while(serFwrFree() != FOUTBUFSIZE);
  BitWrPortI(PDDR, &PDDRShadow, 0, 5);
  a7_serFwaitForString("\r>", 0);

  // Disconnect from the remote device
  serFputs("dis\r");
  a7_serFwaitForString("\r>", 0);

  serFclose();
}