/**************************************************************************
LEDandSwitchCallee.c
A7 Engineering, 2004

This program is used with RCM3000, RCM3100, RCM3200, RCM3300, and
RCM3400 series controllers with an EmbeddedBlue eb506 radio module.

Description
===========
This sample is used to connect two RabbitCore modules each connected to
Z-World prototyping boards. Wireless communication is used to transmit
the current button state between boards and this is used to control the
remote devices LED.

To properly run this sample, you will need two RCM3200 boards
with an A7Enginnering eb506 module attached to each RabitCore.
Run this program (the callee) on one board and run
"LED and Switch Caller.c" (the caller) on the other board.

// IMPORTANT NOTE
// You must run the callee FIRST
// The callee will initialize and wait for the connection
// request from caller.

This program will receive a request for connection from another
eb506 module.  Once a connection is established, the user can use
the switches (S2 and S3) on the prototyping board to toggle the
LEDs on the other board.

Instructions
============
1. Verify that the eb506 is configured to use serial port F through
    jumpers J1 and J2.
2. Compile and run this program.

**************************************************************************/
#use a7eng_eb506.lib
#class auto

#define LED_DS1 6 // LED, port G bit 6
#define LED_DS2 7 // LED, port G bit 7
#define SWITCH_S2 1 // Switch, port G bit 1
#define SWITCH_S3 0 // Switch, port G bit 0

#define BAUD_RATE 9600L

void main()
{
  auto char szPortFData;
  auto int nDataAvailableOnF, nSwitchS2, nSwitchS3;

  // Open the serial port for communications and initialize the eb506
  serFopen(BAUD_RATE);
  a7_serFeb506Init();

  // Initialize the LEDs
  WrPortI(PGDDR, &PGDDRShadow, 0xC0 | PGDDRShadow);
  BitWrPortI(PGDR, &PGDRShadow, 1, LED_DS1);
  BitWrPortI(PGDR, &PGDRShadow, 1, LED_DS2);

  while(1)
  {
    // Read data from eb506 and update the LEDs
    nDataAvailableOnF = serFrdUsed();
    if(nDataAvailableOnF > 0)
    {
      serFread(&szPortFData, 1, 10);
      switch(szPortFData)
      {
      case '0':
        BitWrPortI(PGDR, &PGDRShadow, 0, LED_DS1);
        break;
      case '1':
        BitWrPortI(PGDR, &PGDRShadow, 1, LED_DS1);
        break;
      case '2':
        BitWrPortI(PGDR, &PGDRShadow, 0, LED_DS2);
        break;
      case '3':
        BitWrPortI(PGDR, &PGDRShadow, 1, LED_DS2);
        break;
      default:
        break;
      }
    }

    // Check for changes in the switch state
    if(BitRdPortI(PGDR, SWITCH_S2) ^ nSwitchS2)
    {
      nSwitchS2 = BitRdPortI(PGDR, SWITCH_S2);
      if(!nSwitchS2)
        serFputc('0');
      else
        serFputc('1');
    }

    if(BitRdPortI(PGDR, SWITCH_S3) ^ nSwitchS3)
    {
      nSwitchS3 = BitRdPortI(PGDR, SWITCH_S3);
      if(!nSwitchS3)
        serFputc('2');
      else
        serFputc('3');
    }
  }

  serFclose();
}