/**************************************************************************
FirmwareUpgrade.c
A7 Engineering, 2004

This program is used with RCM3000, RCM3100, RCM3200, RCM3300, and
RCM3400 series controllers with an EmbeddedBlue eb506 radio module.

Description
===========
This program uses the RabbitCore Module as a pass-through to enable
direct communications between the PC and the eb506 module for upgrading
the firmware. When it is running, the A7 Engineering firmware upgrade
application will be able to connect to the eb506 module and load a new
firmware image onto it.

Instructions
============
1. Verify that the eb506 module is configured for serial communications
    at 9600bps
2. Verify that the eb506 is configured to use serial port F through
    jumpers J1 and J2.
3. Compile this program to flash on an RCM prototyping board with eb506
    using the "PROG" cable.
4. Connect the PC and RabbitCore using the "DIAG" cable
5. Run the A7 Engineering firmware upgrade utility.

**************************************************************************/
#define  BAUD_RATE		9600L
#define  UPGRADE_RATE	115200L
#define  AINBUFSIZE		127
#define  AOUTBUFSIZE	127
#define  FINBUFSIZE		127
#define  FOUTBUFSIZE	127

#use a7eng_eb506.lib
#class auto

void main()
{
  auto char szPortAData[128];
  auto char szPortFData[128];
  auto int nDataAvailableOnA, nDataAvailableOnF;
  auto int nDataReadFromA, nDataReadFromF;

  // Open the serial port for communications and initialize the eb506
  serFopen(BAUD_RATE);
  a7_serFeb506Init();

  // Put the eb506 module into firmware upgrade mode
  serFputs("set mode bcsp\r");
  a7_serFwaitForString("\r>", 0);

  // Change the communications parameters to match the settings for
  // firmware update. The baud rate is increased to speed this up and
  // even parity is used for reliability.
  serFclose();
  serAopen(UPGRADE_RATE);
  serFopen(UPGRADE_RATE);
  serAparity(PARAM_EPARITY);
  serFparity(PARAM_EPARITY);

  while(1)
  {
    BigLoopTop();

    // Read data from the diagnostics port and send it to the eb506
    costate
    {
      nDataAvailableOnA = serArdUsed();
      if(nDataAvailableOnA > 0)
      {
        wfd nDataReadFromA = cof_serAread(szPortAData, nDataAvailableOnA, 50);
        wfd cof_serFwrite(szPortAData, nDataReadFromA);
      }
    }

    // Read data from the eb506 and send it to the diagostics port
    costate
    {
      nDataAvailableOnF = serFrdUsed();
      if(nDataAvailableOnF > 0)
      {
        wfd nDataReadFromF = cof_serFread(szPortFData, nDataAvailableOnF, 50);
        wfd cof_serAwrite(szPortFData, nDataReadFromF);
      }
    }
  }
}