/**************************************************************************
Passthrough.c
A7 Engineering, 2004

This program is used with RCM3000, RCM3100, RCM3200, RCM3300, and
RCM3400 series controllers with an EmbeddedBlue eb506 radio module.

Description
===========
This program uses the RabbitCore Module as a pass-through to enable
direct communications between the PC and the eb506 module. When it is
running, a terminal program on the PC such as HyperTerminal can be used
to directly control the eb506 module.

Instructions
============
1. Verify that the eb506 is configured to use serial port F through
    jumpers J1 and J2.
2. Compile this program to flash on an RCM prototyping board with eb506
    using the "PROG" cable.
3. Connect the PC and RabbitCore using the "DIAG" cable
4. Connect using HyperTerminal.
5. The RabbitCore is now a passthrough to the eb506.

**************************************************************************/
#use a7eng_eb506.lib
#class auto

#define BAUD_RATE 9600L
#define BUFFER_SIZE 32

void main()
{
  auto char szPortAData[BUFFER_SIZE];
  auto char szPortFData[BUFFER_SIZE];
  auto int nDataAvailableOnA, nDataAvailableOnF;
  auto int nDataReadFromA, nDataReadFromF;

  // Open the serial port for communications and initialize the eb506
  serAopen(BAUD_RATE);
  serFopen(BAUD_RATE);
  a7_serFeb506Init();

  while(1)
  {
    BigLoopTop();

    // Read data from the diagnostics port and send it to the eb506
    costate
    {
      nDataAvailableOnA = serArdUsed();

      // Ensure we don't overflow our buffer
      if(nDataAvailableOnA > BUFFER_SIZE)
        nDataAvailableOnA = BUFFER_SIZE;

      if(nDataAvailableOnA > 0)
      {
        wfd nDataReadFromA = cof_serAread(szPortAData, nDataAvailableOnA, 50);
        wfd cof_serFwrite(szPortAData, nDataReadFromA);
      }
    }

    // Read data from the eb506 and send it to the diagnostics port
    costate
    {
      nDataAvailableOnF = serFrdUsed();

      // Ensure we don't overflow our buffer
      if(nDataAvailableOnF > BUFFER_SIZE)
        nDataAvailableOnF = BUFFER_SIZE;

      if(nDataAvailableOnF > 0)
      {
        wfd nDataReadFromF = cof_serFread(szPortFData, nDataAvailableOnF, 50);
        wfd cof_serAwrite(szPortFData, nDataReadFromF);
      }
    }
  }
}