//
//	Dial-Up Networking Sample Application for the eb501 on the PIC Platform
//
//	File:			DUN.c
//	Date:			August 8, 2006
//	Hardware:		PICDEM 2 PLUS demo board, PIC18F452 controller, eb501 serial Bluetooth module
//	Description:	This sample will open the com port on the PIC, open a DUN connection to a Bluetooth
//					enabled phone, and issue AT commands to dial a phone number.
//	Notes:			The Bluetooth address of the remote must be entered by the user	in this source file.
//					Many phones will not be able to dial a number, and therefore the common return is checked for.
//					Ensure that the eb's MODE line is NOT connected to any I/O lines on the PICDEM board.
//
//	Copyright 2005-2006 A7 Engineering Inc. 
//	Permission is granted to freely copy, modify, or redistribute this software.
//

// --- Includes ---

// Include the A7 eb501 PIC18F helper API library
#include "eb501PICLib.h"

// --- Globals ---

char g_szACK_CR_Caret[6] = "ACK\r>";
char g_szOK[3] = "OK";
char g_szNOCARRIER[11] = "NO CARRIER";

// --- Functions ---

// Main
void main()
{
  	// Open the USART configured as 9600/8/N/1 in polled mode for transmit, and interrupt-based receive
	UARTOpen(9600);

	// Do any eb501 specific work
	eb501Init();

  	// Connect to the remote device
	UARTWriteString("con 00:0E:07:0B:90:0F dun\r");

	// Wait for the ACK (indicating correct command syntax) and the caret (indicating successful connection)
	UARTWaitForString(g_szACK_CR_Caret, 100);

	// You could also read the eb's STATUS line to determine if the Bluetooth connection is up. If the STATUS
	// line is low, there is an active Bluetooth connection

	// At this point, enter the passkey '0000' into your phone (if you have not paired the eb501
	// and that phone together previously) to complete the dial-up networking connection. You may 
	// want to adjust this delay in the begining. After you've paired, no delay is required
#if 0
	DelayMs(10000);
#endif
	
	// Now check that the phone is receiving AT commands correctly (this varies from phone to phone)
	UARTWriteString("AT\r");

	// Wait for the OK
	UARTWaitForString(g_szOK, 100);

	// Wait a bit
	DelayMs(1000);

	// Now try to command the phone to dial a number
	// Note that its possible to send all the bytes without a delay in between, but in some cases the 
	// later method is more reliable
#if 1
	UARTWriteString("ATD18586797708\r");
#else
	UARTWriteByte('a');
	DelayMs(100);
	UARTWriteByte('t');
	DelayMs(100);
	UARTWriteByte('d');
	DelayMs(100);
	UARTWriteByte('6');
	DelayMs(100);
	UARTWriteByte('7');
	DelayMs(100);
	UARTWriteByte('9');	
	DelayMs(100);
	UARTWriteByte('7');
	DelayMs(100);
	UARTWriteByte('7');
	DelayMs(100);
	UARTWriteByte('0');
	DelayMs(100);
	UARTWriteByte('8');
	DelayMs(100);
	UARTWriteByte(0xD);
#endif

	// Wait a bit
	DelayMs(1000);

	// Wait for the likely error (most phones will seem to begin the call, and return an error)
	UARTWaitForString(g_szNOCARRIER, 100);

	// Close the UART
	UARTClose();

	// Loop forever, or main() will be called continuously
	while(1) 
		;
}
