//
//	Data Echo and LED Sample Application for the eb501 on the PIC Platform
//
//	File:			EchoLED.c
//	Date:			August 4, 2006
//	Hardware:		PICDEM 2 PLUS demo board, PIC18F452 controller, eb501 serial Bluetooth module
//	Description:	This sample will open the com port on the PIC, connect to a remote eb module, and
//					transmit and receive serial data to and from the remote. On the remote side, using
//					a terminal window, the user can enter a number from 0 to 9, and watch the LEDs on
//					the board change to represent that number in binary. Any other characters sent will
//					be echoed back to the remote.
//	Notes:			The Bluetooth address of the remote must be entered by the user	in this source file.
//					This sample is board specific due to the LED's port assignment. On the PICDEM 2 PLUS
//					board, ensure that Jumper J6 is in place to tie PORTB to the 4 LEDs. Also, ensure
//					that the eb501's MODE line is NOT connected to any PORTB I/O lines.
//
//	Copyright 2005-2006 A7 Engineering Inc. 
//	Permission is granted to freely copy, modify, or redistribute this software.
//

// --- Includes ---

// Include the A7 eb501 PIC18F helper API library
#include "eb501PICLib.h"

// --- Globals ---

char g_szACK_CR_Caret[6] = "ACK\r>";

// --- Prototypes ---

void RxIntHandler(void);

// --- Functions ---

// Interrupt vector jump statement
#pragma code rx_interrupt = 0x8
void rx_int (void)
{
  	_asm 
		goto RxIntHandler 
	_endasm
}

// Interrupt handler
#pragma code
#pragma interrupt RxIntHandler
void RxIntHandler (void)
{
  	unsigned char c;

  	// Read a char from the USART
  	c = UARTReadByte();
	
	// Display the received value on the LEDs
  	if(c >= '0' && c <= '9')
    {
      	c -= '0';
		PortBWrite(c);
   	}
   	else
   	{
      	// Otherwise, echo the character back
		UARTWriteByte(c);	
   	}

   	// Clear the interrupt flag 
   	PIR1bits.RCIF = 0;
}

// Main
void main (void)
{
	// Clear the LEDs
	PortBWrite(0);

  	// Open the USART configured as 9600/8/N/1 in polled mode for transmit, and interrupt-based receive
	UARTOpen(9600);

	// Do any eb501 specific work
	eb501Init();

  	// Connect to the remote device
	UARTWriteString("con 00:0C:84:00:38:AD\r");

	// Wait for the ACK (indicating correct command syntax) and the caret (indicating successful connection)
	UARTWaitForString(g_szACK_CR_Caret, 100);

	// You could also read the eb's STATUS line to determine if the Bluetooth connection is up. If the STATUS
	// line is low, there is an active Bluetooth connection

	UARTWriteString("\r\rEnter a number or character:\r");

  	// Enable interrupt priority 
  	RCONbits.IPEN = 1;

  	// Make receive interrupt high priority 
  	IPR1bits.RCIP = 1;

  	// Enable all high priority interrupts 
  	INTCONbits.GIEH = 1;                                     

  	// Loop forever receiving data, and also so main() doesn't keep getting called
  	while (1)
    	;
}
