//
//	Bluetooth Address Sample Application for the eb501 on the PIC Platform
//
//	File:			GetAddress.c
//	Date:			August 9, 2006
//	Hardware:		PICDEM 2 PLUS demo board, PIC18F452 controller, eb501 serial Bluetooth module
//	Description:	This sample will open the com port on the PIC, obtain the local eb module's Bluetooth
//					address, connect to a remote eb module, and transmit the address to the remote module.
//	Notes:			The Bluetooth address of the remote must be entered by the user	in this source file.
//					Ensure that the eb's MODE line is NOT connected to any I/O lines on the PICDEM board.
//
//	Copyright 2005-2006 A7 Engineering Inc. 
//	Permission is granted to freely copy, modify, or redistribute this software.
//

// --- Includes ---

// Include the A7 eb501 PIC18F helper API library
#include "eb501PICLib.h"

// --- Defines ---

// The length of a Bluetooth address in ASCII, plus 1
#define BUFFER_SIZE 18

// --- Globals ---

char g_szACK_CR[5] = "ACK\r";
char g_szACK_CR_Caret[6] = "ACK\r>";
char g_szCR_Caret[3] = "\r>";

// --- Functions ---

// Main
void main()
{
	char szAddr[BUFFER_SIZE];
	int nBytesRead;

  	// Open the USART configured as 9600/8/N/1 in polled mode for transmit, and interrupt-based receive
	UARTOpen(9600);

	// Do any eb501 specific work
	eb501Init();

	// Request our eb501 address
	UARTWriteString("get address\r");

	// Wait for the ACK
	UARTWaitForString(g_szACK_CR, 100);

	// Read local address from return of the command
	nBytesRead = UARTReadString(szAddr, 17, 50);
	if(nBytesRead > 0)
	{
		// Terminate the string
		szAddr[17] = 0;
	}

	// Wait for the Caret
	UARTWaitForString(g_szCR_Caret, 100);

  	// Connect to the remote device
	UARTWriteString("con 00:0C:84:00:38:AD\r");

	// Wait for the ACK (indicating correct command syntax) and the caret (indicating successful connection)
	UARTWaitForString(g_szACK_CR_Caret, 100);

	// You could also read the eb's STATUS line to determine if the Bluetooth connection is up. If the STATUS
	// line is low, there is an active Bluetooth connection

	// Send over our address
	UARTWriteString("\r\rYou are connected to peer: ");
	UARTWriteBuffer(szAddr, strlen(szAddr)+1);
	
	// Close the UART
	UARTClose();

	// Loop forever so main() doesn't keep getting called
	while(1)
		;
}
