//
//	"Hello, world!" Sample Application for the eb501 on the PIC platform
//
//	File:			HelloWorld.c
//	Date:			August 3, 2006
//	Hardware:		PICDEM 2 PLUS demo board, PIC18F452 controller, eb501 serial Bluetooth module
//	Description:	This sample will open the com port on the PIC, connect to a remote eb module,
//					send some data, switch the eb to command mode, and disconnect from the peer.
//	Notes:			The Bluetooth address of the remote must be entered by the user	in this source file		
//					Ensure that the eb's MODE line is NOT connected to any I/O lines on the PICDEM board.
//
//	Copyright 2005-2006 A7 Engineering Inc. 
//	Permission is granted to freely copy, modify, or redistribute this software.
//

// --- Includes ---

// Include the A7 eb501 PIC18F helper API library
#include "eb501PICLib.h"

// --- Globals ---

char g_szACK_CR_Caret[6] = "ACK\r>";
char g_szCR_Caret[3] = "\r>";
char g_nCount = 5;

// --- Functions ---

// Main
void main()
{
  	// Open the USART configured as 9600/8/N/1 in polled mode for transmit, and interrupt-based receive
	UARTOpen(9600);

	// Do any eb501 specific work
	eb501Init();

  	// Connect to the remote device
	UARTWriteString("con 00:0C:84:00:38:AD\r");

	// Wait for the ACK (indicating correct command syntax) and the caret (indicating successful connection)
	UARTWaitForString(g_szACK_CR_Caret, 100);

	// You could also read the eb's STATUS line to determine if the Bluetooth connection is up. If the STATUS
	// line is low, there is an active Bluetooth connection

	// Send out some banners
	UARTWriteString("\r\r");
	while(g_nCount--)
	{
		UARTWriteString("Hello, world!\r\n");
		DelayMs(1000);
	}

	// Switch to command mode
	DelayMs(2000);				// Delay at least 1000ms
	UARTWriteString("+++");		// Send "+++"	
	DelayMs(2000);				// Delay at least 1000ms

	// Wait for the caret
	UARTWaitForString(g_szCR_Caret, 100);

	// Disconnect from the remote device
	UARTWriteString("dis\r");
	UARTWaitForString(g_szACK_CR_Caret, 100);

	// Close the UART
	UARTClose();

	// Loop forever, or main() will be called continuously
	while(1) 
		;
}
