//
//	Data Mode and Command Mode Switching Sample Application for the eb501 on the PIC Platform
//
//	File:			ModeSwitch.c
//	Date:			August 11, 2006
//	Hardware:		PICDEM 2 PLUS demo board, PIC18F452 controller, eb501 serial Bluetooth module
//	Description:	This sample will open the com port on the PIC, connect to a remote eb module, send
//					some data in data mode, switch to command mode using SOFTWARE, return to data mode,
//					send some data in data mode again, switch to command mode using HARDWARE, return to data
//					mode again, and finally send some data in data mode.
//	Notes:			The Bluetooth address of the remote must be entered by the user	in this source file.
//					This sample is board specific since an I/O line is required. On the PICDEM 2 PLUS board, 
//					ensure the eb501's MODE pin is connected to PORTB0 (RB0).
//
//	Copyright 2005-2006 A7 Engineering Inc. 
//	Permission is granted to freely copy, modify, or redistribute this software.
//

// --- Includes ---

// Include the A7 eb501 PIC18F helper API library
#include "eb501PICLib.h"

// --- Globals ---

char g_szACK_CR_Caret[6] = "ACK\r>";
char g_szCR_Caret[3] = "\r>";

// --- Functions ---

// Main
void main()
{
	// Initially, drive the eb501 MODE line high
	PortBWrite(1);

  	// Open the USART configured as 9600/8/N/1 in polled mode for transmit, and interrupt-based receive
	UARTOpen(9600);

	// Do any eb501 specific work
	eb501Init();

  	// Connect to the remote device
	UARTWriteString("con 00:0C:84:00:38:AD\r");

	// Wait for the ACK (indicating correct command syntax) and the caret (indicating successful connection)
	UARTWaitForString(g_szACK_CR_Caret, 100);

	// You could also read the eb's STATUS line to determine if the Bluetooth connection is up. If the STATUS
	// line is low, there is an active Bluetooth connection

	UARTWriteString("\r\rCurrently in Data Mode, about to switch to Command Mode using SOFTWARE\r");

	// Wait a little bit
	DelayMs(1000);

	// -- Switch to command mode (SOFTWARE SWITCH) --

	DelayMs(2000);				// Delay at least 1000ms
	UARTWriteString("+++");		// Send "+++"	
	DelayMs(2000);				// Delay at least 1000ms

	// Wait for the caret
	UARTWaitForString(g_szCR_Caret, 100);

	// Wait a little bit
	DelayMs(1000);

	// - Now you can issue commands, as per the other examples -

	// Return to data mode using software
	UARTWriteString("ret\r");
	UARTWaitForString(g_szACK_CR_Caret, 100);

	UARTWriteString("Back in Data Mode, about to switch to Command Mode using HARDWARE\r");

	// Wait a little bit
	DelayMs(1000);

	// -- Switch to command mode (HARDWARE SWITCH) --

	// Drive the eb501's MODE line low
	PortBWrite(0);

	// Wait for the caret
	UARTWaitForString(g_szCR_Caret, 100);

	// Wait a little bit
	DelayMs(1000);

	// - Now you can issue commands, as per the other examples -

	// Return to data mode using hardware
	PortBWrite(1);
	UARTWaitForString(g_szACK_CR_Caret, 100);

	UARTWriteString("Finished in Data Mode\r");

	// Wait a little bit
	DelayMs(1000);

	// Close the UART
	UARTClose();

	// Loop forever so main() doesn't keep getting called
	while(1)
		;
}
